@@ -1,11 +1,11 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * goc-line.c :  
+ * goc-line.c :
  *
  * Copyright (C) 2009 Jean Brefort (jean.brefort@normalesup.org)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -241,7 +241,7 @@ goc_line_init_style (G_GNUC_UNUSED GocStyledItem *item, GOStyle *style)
 	if (style->line.auto_dash)
 		style->line.dash_type = GO_LINE_SOLID;
 	if (style->line.auto_color)
-		style->line.color = RGBA_BLACK;
+		style->line.color = GO_COLOR_BLACK;
 	if (style->line.auto_fore)
 		style->line.fore  = 0;
 }
