@@ -22,11 +22,7 @@
 #ifndef GOG_CHART_MAP_H
 #define GOG_CHART_MAP_H
 
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-series.h>
-#include <goffice/utils/go-path.h>
-#include <goffice/utils/go-line.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -47,11 +43,11 @@ GogAxisMap	*gog_chart_map_get_axis_map 	(GogChartMap *map, unsigned int index);
 gboolean	 gog_chart_map_is_valid 	(GogChartMap *map);
 void		 gog_chart_map_free 		(GogChartMap *map);
 
-GOPath 		*gog_chart_map_make_path 	(GogChartMap *map, double const *x, double const *y, 
+GOPath 		*gog_chart_map_make_path 	(GogChartMap *map, double const *x, double const *y,
 						 int n_points, GOLineInterpolation interpolation,
 						 gboolean skip_invalid, gpointer data);
-GOPath 		*gog_chart_map_make_close_path 	(GogChartMap *map, double const *x, double const *y, 
-						 int n_points, 
+GOPath 		*gog_chart_map_make_close_path 	(GogChartMap *map, double const *x, double const *y,
+						 int n_points,
 						 GogSeriesFillType fill_type);
 
 GogChartMapPolarData *gog_chart_map_get_polar_parms (GogChartMap *map);
