@@ -182,7 +182,7 @@ go_combo_box_popup_hide_unconditional (GOComboBox *combo_box)
 	GObject *pdc;
 
 	g_return_if_fail (combo_box != NULL);
-	g_return_if_fail (IS_GO_COMBO_BOX (combo_box));
+	g_return_if_fail (GO_IS_COMBO_BOX (combo_box));
 
 	gtk_widget_hide (combo_box->priv->toplevel);
 	gtk_widget_hide (combo_box->priv->popup);
@@ -277,7 +277,7 @@ go_combo_box_class_init (GObjectClass *object_class)
 				       _("Add tearoffs to menus"),
 				       _("Whether dropdowns should have a tearoff menu item"),
 				       FALSE,
-				       GSF_PARAM_STATIC | 
+				       GSF_PARAM_STATIC |
 				       G_PARAM_READABLE));
 	widget_class->style_set = go_combo_box_style_set;
 
@@ -526,8 +526,10 @@ go_combo_box_button_press (GtkWidget *widget, GdkEventButton *event, GOComboBox
 static void
 cb_state_change (GtkWidget *widget, GtkStateType old_state, GOComboBox *combo_box)
 {
-	GtkStateType const new_state = GTK_WIDGET_STATE(widget);
-	gtk_widget_set_state (combo_box->priv->display_widget, new_state);
+	GtkStateType const new_state = GTK_WIDGET_STATE (widget);
+	if (combo_box->priv->display_widget)
+		gtk_widget_set_state (combo_box->priv->display_widget,
+				      new_state);
 }
 
 static void
@@ -601,17 +603,20 @@ GSF_CLASS (GOComboBox, go_combo_box,
 /* protected */ void
 go_combo_box_set_display (GOComboBox *combo_box, GtkWidget *display_widget)
 {
-	g_return_if_fail (IS_GO_COMBO_BOX (combo_box));
-	g_return_if_fail (GTK_IS_WIDGET (display_widget));
+	g_return_if_fail (GO_IS_COMBO_BOX (combo_box));
+	g_return_if_fail (!display_widget || GTK_IS_WIDGET (display_widget));
 
-	if (combo_box->priv->display_widget != NULL &&
-	    combo_box->priv->display_widget != display_widget)
+	if (display_widget == combo_box->priv->display_widget)
+		return;
+
+	if (combo_box->priv->display_widget)
 		gtk_container_remove (GTK_CONTAINER (combo_box),
 				      combo_box->priv->display_widget);
-
 	combo_box->priv->display_widget = display_widget;
 
-	gtk_box_pack_start (GTK_BOX (combo_box), display_widget, TRUE, TRUE, 0);
+	if (display_widget)
+		gtk_box_pack_start (GTK_BOX (combo_box), display_widget,
+				    TRUE, TRUE, 0);
 }
 
 static gboolean
@@ -636,7 +641,7 @@ go_combo_set_tearoff_state (GOComboBox *combo,
 			     gboolean  torn_off)
 {
 	g_return_if_fail (combo != NULL);
-	g_return_if_fail (IS_GO_COMBO_BOX (combo));
+	g_return_if_fail (GO_IS_COMBO_BOX (combo));
 
 	if (combo->priv->torn_off != torn_off) {
 		combo->priv->torn_off = torn_off;
@@ -696,8 +701,7 @@ go_combo_box_construct (GOComboBox *combo,
 	GtkWidget *tearable;
 	GtkWidget *vbox;
 
-	g_return_if_fail (IS_GO_COMBO_BOX (combo));
-	g_return_if_fail (GTK_IS_WIDGET (display_widget));
+	g_return_if_fail (GO_IS_COMBO_BOX (combo));
 
 	GTK_BOX (combo)->spacing = 0;
 	GTK_BOX (combo)->homogeneous = FALSE;
@@ -750,7 +754,7 @@ void
 go_combo_box_set_title (GOComboBox *combo, char const *title)
 {
 	GOComboBoxClass *klass = G_TYPE_INSTANCE_GET_CLASS (combo,
-		GO_COMBO_BOX_TYPE, GOComboBoxClass);
+		GO_TYPE_COMBO_BOX, GOComboBoxClass);
 
 	g_return_if_fail (klass != NULL);
 
@@ -777,7 +781,7 @@ go_combo_box_get_title (GOComboBox *combo)
 void
 go_combo_box_set_tearable (GOComboBox *combo, gboolean tearable)
 {
-	g_return_if_fail (IS_GO_COMBO_BOX (combo));
+	g_return_if_fail (GO_IS_COMBO_BOX (combo));
 
 	if (tearable){
 		gtk_widget_show (combo->priv->tearable);
@@ -790,7 +794,7 @@ go_combo_box_set_tearable (GOComboBox *combo, gboolean tearable)
 void
 go_combo_box_set_relief (GOComboBox *combo, GtkReliefStyle relief)
 {
-	g_return_if_fail (IS_GO_COMBO_BOX (combo));
+	g_return_if_fail (GO_IS_COMBO_BOX (combo));
 
 	gtk_button_set_relief (GTK_BUTTON (combo->priv->arrow_button), relief);
 	if (GTK_IS_BUTTON (combo->priv->display_widget))
