@@ -57,7 +57,6 @@ static GType gog_box_plot_view_get_type (void);
 
 #ifdef GOFFICE_WITH_GTK
 #include <goffice/gtk/goffice-gtk.h>
-#include <glade/glade-xml.h>
 
 static void
 cb_gap_changed (GtkAdjustment *adj, GObject *boxplot)
@@ -74,22 +73,22 @@ cb_layout_changed (GtkComboBox *box, GObject *boxplot)
 static void
 cb_outliers_changed (GtkToggleButton *btn, GObject *boxplot)
 {
-	GladeXML *gui = GLADE_XML (g_object_get_data (G_OBJECT (btn), "state"));
+	GtkBuilder *gui = GTK_BUILDER (g_object_get_data (G_OBJECT (btn), "state"));
 	GtkWidget *w;
 	gboolean outliers = gtk_toggle_button_get_active (btn);
 	if (outliers) {
-		w = glade_xml_get_widget (gui, "diameter-label");
+		w = go_gtk_builder_get_widget (gui, "diameter-label");
 		gtk_widget_show (w);
-		w = glade_xml_get_widget (gui, "diameter");
+		w = go_gtk_builder_get_widget (gui, "diameter");
 		gtk_widget_show (w);
-		w = glade_xml_get_widget (gui, "diam-pc-label");
+		w = go_gtk_builder_get_widget (gui, "diam-pc-label");
 		gtk_widget_show (w);
 	} else {
-		w = glade_xml_get_widget (gui, "diameter-label");
+		w = go_gtk_builder_get_widget (gui, "diameter-label");
 		gtk_widget_hide (w);
-		w = glade_xml_get_widget (gui, "diameter");
+		w = go_gtk_builder_get_widget (gui, "diameter");
 		gtk_widget_hide (w);
-		w = glade_xml_get_widget (gui, "diam-pc-label");
+		w = go_gtk_builder_get_widget (gui, "diam-pc-label");
 		gtk_widget_hide (w);
 	}
 	g_object_set (boxplot, "outliers", outliers, NULL);
@@ -109,29 +108,29 @@ gog_box_plot_pref (GogObject *obj,
 	GogBoxPlot *boxplot = GOG_BOX_PLOT (obj);
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_boxes"));
-	char	 *path = g_build_filename (dir, "gog-boxplot-prefs.glade", NULL);
-	GladeXML *gui = go_glade_new (path, "gog_box_plot_prefs", GETTEXT_PACKAGE, cc);
+	char	 *path = g_build_filename (dir, "gog-boxplot-prefs.ui", NULL);
+	GtkBuilder *gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
                 return NULL;
 
-	w = glade_xml_get_widget (gui, "gap_spinner");
+	w = go_gtk_builder_get_widget (gui, "gap_spinner");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), boxplot->gap_percentage);
 	g_signal_connect (G_OBJECT (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w))),
 		"value_changed",
 		G_CALLBACK (cb_gap_changed), boxplot);
 
-	w = glade_xml_get_widget (gui, "layout");
+	w = go_gtk_builder_get_widget (gui, "layout");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (w), boxplot->vertical);
 	g_signal_connect (w, "changed", G_CALLBACK (cb_layout_changed), boxplot);
 
-	w = glade_xml_get_widget (gui, "show-outliers");
+	w = go_gtk_builder_get_widget (gui, "show-outliers");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), boxplot->outliers);
 	g_object_set_data (G_OBJECT (w), "state", gui);
 	g_signal_connect (w, "toggled", G_CALLBACK (cb_outliers_changed), boxplot);
 
-	w = glade_xml_get_widget (gui, "diameter");
+	w = go_gtk_builder_get_widget (gui, "diameter");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), boxplot->radius_ratio * 200.);
 	g_signal_connect (G_OBJECT (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w))),
 		"value_changed",
@@ -139,15 +138,15 @@ gog_box_plot_pref (GogObject *obj,
 
 	if (!boxplot->outliers) {
 		gtk_widget_hide (w);
-		w = glade_xml_get_widget (gui, "diameter-label");
+		w = go_gtk_builder_get_widget (gui, "diameter-label");
 		gtk_widget_hide (w);
-		w = glade_xml_get_widget (gui, "diam-pc-label");
+		w = go_gtk_builder_get_widget (gui, "diam-pc-label");
 		gtk_widget_hide (w);
 	}
 
-	w = glade_xml_get_widget (gui, "gog_box_plot_prefs");
-	g_object_set_data_full (G_OBJECT (w),
-		"state", gui, (GDestroyNotify)g_object_unref);
+	w = go_gtk_builder_get_widget (gui, "gog_box_plot_prefs");
+	g_object_set_data (G_OBJECT (w), "state", gui);
+	g_signal_connect (G_OBJECT (w), "destroy", G_CALLBACK (g_object_unref), gui);
 
 	return w;
 }
@@ -158,8 +157,10 @@ gog_box_plot_populate_editor (GogObject *item,
 			      G_GNUC_UNUSED GogDataAllocator *dalloc,
 			      GOCmdContext *cc)
 {
-	go_editor_add_page (editor, gog_box_plot_pref (item, dalloc, cc), _("Properties"));
-	
+	GtkWidget *w =  gog_box_plot_pref (item, dalloc, cc);
+	go_editor_add_page (editor,w, _("Properties"));
+	g_object_unref (w);
+
 	(GOG_OBJECT_CLASS(gog_box_plot_parent_klass)->populate_editor) (item, editor, dalloc, cc);
 }
 #endif
@@ -176,7 +177,7 @@ typedef struct {
 	GogSeries base;
 	int	 gap_percentage;
 	double vals[5];
-	double *svals; //sorted data
+	double *svals; /* sorted data */
 	int nb_valid;
 } GogBoxPlotSeries;
 typedef GogSeriesClass GogBoxPlotSeriesClass;
@@ -355,28 +356,28 @@ gog_box_plot_class_init (GogPlotClass *gog_plot_klass)
 	gobject_klass->get_property = gog_box_plot_get_property;
 	gobject_klass->finalize = gog_box_plot_finalize;
 	g_object_class_install_property (gobject_klass, BOX_PLOT_PROP_GAP_PERCENTAGE,
-		g_param_spec_int ("gap-percentage", 
+		g_param_spec_int ("gap-percentage",
 			_("Gap percentage"),
 			_("The padding around each group as a percentage of their width"),
-			0, 500, 150, 
+			0, 500, 150,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, BOX_PLOT_PROP_VERTICAL,
-		g_param_spec_boolean ("vertical", 
+		g_param_spec_boolean ("vertical",
 			_("Vertical"),
 			_("Whether the box-plot should be vertical instead of horizontal"),
-			FALSE, 
+			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, BOX_PLOT_PROP_OUTLIERS,
-		g_param_spec_boolean ("outliers", 
+		g_param_spec_boolean ("outliers",
 			_("Outliers"),
 			_("Whether outliers should be taken into account and displayed"),
-			FALSE, 
+			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, BOX_PLOT_PROP_RADIUS_RATIO,
-		g_param_spec_double ("radius-ratio", 
+		g_param_spec_double ("radius-ratio",
 			_("Radius ratio"),
 			_("The ratio between the radius of the circles representing outliers and the rectangle width"),
-			0., 0.5, 0.125, 
+			0., 0.5, 0.125,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_object_klass->type_name	= gog_box_plot_type_name;
@@ -433,15 +434,15 @@ gog_box_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 	int num_ser = 1;
 
 	area = gog_chart_view_get_plot_area (view->parent);
-	chart_map = gog_chart_map_new (chart, area, 
-				       GOG_PLOT (model)->axis[GOG_AXIS_X], 
+	chart_map = gog_chart_map_new (chart, area,
+				       GOG_PLOT (model)->axis[GOG_AXIS_X],
 				       GOG_PLOT (model)->axis[GOG_AXIS_Y],
 				       NULL, FALSE);
 	if (!gog_chart_map_is_valid (chart_map)) {
 		gog_chart_map_free (chart_map);
 		return;
 	}
-	
+
 	if (model->vertical) {
 		map = gog_chart_map_get_axis_map (chart_map, 1);
 		ser_map = gog_chart_map_get_axis_map (chart_map, 0);
@@ -473,7 +474,6 @@ gog_box_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 		if (model->outliers) {
 			double l1, l2, m1, m2, d, r = 2. * hrect * model->radius_ratio;
 			int i = 0;
-			style->outline = style->line;
 			d = series->vals[3] - series->vals[1];
 			l1 = series->vals[1] - d * 1.5;
 			l2 = series->vals[1] - d * 3.;
@@ -624,14 +624,6 @@ gog_box_plot_series_update (GogObject *obj)
 		gog_box_plot_series_parent_klass->update (obj);
 }
 
-static void
-gog_box_plot_series_init_style (GogStyledObject *gso, GOStyle *style)
-{
-	((GogStyledObjectClass*) gog_box_plot_series_parent_klass)->init_style (gso, style);
-
-	style->outline.dash_type = GO_LINE_NONE;
-}
-
 static void
 gog_box_plot_series_finalize (GObject *obj)
 {
@@ -643,12 +635,10 @@ static void
 gog_box_plot_series_class_init (GogObjectClass *obj_klass)
 {
 	GObjectClass *object_class = (GObjectClass *) obj_klass;
-	GogStyledObjectClass *gso_klass = (GogStyledObjectClass*) obj_klass;
 
 	gog_box_plot_series_parent_klass = g_type_class_peek_parent (obj_klass);
 	object_class->finalize = gog_box_plot_series_finalize;
 	obj_klass->update = gog_box_plot_series_update;
-	gso_klass->init_style = gog_box_plot_series_init_style;
 }
 
 GSF_DYNAMIC_CLASS (GogBoxPlotSeries, gog_box_plot_series,
